instrumenttools.TenorTrombone
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone

.. autoclass:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorTrombone.TenorTrombone.TenorTrombone.__repr__
   :noindex:
